@@ -1,6 +1,6 @@
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import Column, Integer, Float, String
-from tools import get_session
+from sqlalchemy_sqlite_session.tools import get_session
 
 Base = declarative_base()
 
@@ -804,11 +804,11 @@ class HappyNumber(Base):
     def add_number(cls, p_issue: str, p_numbers: list):
         """添加一条记录"""
         session = get_session()
-        ins = HappyNumber(p_issue, p_numbers)
+        ins = cls(p_issue, p_numbers)
         session.merge(ins)
         session.commit()
         session.close()
-        print(f">>> merge one data:{p_issue} - {p_numbers}")
+        print(f">>> KL8 merge:{p_issue} - {p_numbers}")
 
 
 class HappyVerify(Base):
