@@ -1,6 +1,6 @@
 from sqlalchemy import Column, String, Integer, Float
 from sqlalchemy.ext.declarative import declarative_base
-from tools import get_session, get_engine
+from sqlalchemy_sqlite_session.tools import get_session, get_engine
 import json
 
 Base = declarative_base()
@@ -114,7 +114,7 @@ class SportNumber(Base):
         session.merge(ins)
         session.commit()
         session.close()
-        print(f">>> merge kill in kills:{p_issue} - {p_numbers}")
+        print(f">>> P3 merge:{p_issue} - {p_numbers}")
 
 
 class ExpertSummary(Base):
@@ -215,30 +215,30 @@ class CaiYanShi(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save_a = Column(String(50))  # 金胆
-    save_b = Column(String(50))  # 银胆
-    save_c = Column(String(50))  # 铜胆
-    kills = Column(String(50))  # 排除
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    mix5 = Column(String(50))  # 五码复式
-    mix6 = Column(String(50))  # 六码复式
-    mix7 = Column(String(50))  # 七码复式
-    multi6 = Column(String(500))  # 组选推荐
-    multi3 = Column(String(500))  # 组三推荐
+    save_a = Column(String)  # 金胆
+    save_b = Column(String)  # 银胆
+    save_c = Column(String)  # 铜胆
+    kills = Column(String)  # 排除
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    mix5 = Column(String)  # 五码复式
+    mix6 = Column(String)  # 六码复式
+    mix7 = Column(String)  # 七码复式
+    multi6 = Column(String)  # 组选推荐
+    multi3 = Column(String)  # 组三推荐
 
     # verify attributes
-    v_save_a = Column(String(50))
-    v_save_b = Column(String(50))
-    v_save_c = Column(String(50))
-    v_kills = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_multi6 = Column(String(50))
-    v_multi3 = Column(String(50))
+    v_save_a = Column(String)
+    v_save_b = Column(String)
+    v_save_c = Column(String)
+    v_kills = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_multi6 = Column(String)
+    v_multi3 = Column(String)
 
     def get_verify(self):
         return [
@@ -262,30 +262,30 @@ class DaiTouDaGe(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    kills = Column(String(50))  # 杀码推荐
-    save1 = Column(String(50))  # 独胆预测
-    save2 = Column(String(50))  # 双胆预测
-    save3 = Column(String(50))  # 三胆预测
-    mix5 = Column(String(50))  # 五码复式
-    mix6 = Column(String(50))  # 六码复式
-    mix7 = Column(String(50))  # 七码复式
-    he = Column(String(50))  # 推荐和值
-    span = Column(String(50))  # 推荐跨度
-    multi6 = Column(String(500))  # 组选推荐
-    result_many = Column(String(500))  # 直选推荐
+    kills = Column(String)  # 杀码推荐
+    save1 = Column(String)  # 独胆预测
+    save2 = Column(String)  # 双胆预测
+    save3 = Column(String)  # 三胆预测
+    mix5 = Column(String)  # 五码复式
+    mix6 = Column(String)  # 六码复式
+    mix7 = Column(String)  # 七码复式
+    he = Column(String)  # 推荐和值
+    span = Column(String)  # 推荐跨度
+    multi6 = Column(String)  # 组选推荐
+    result_many = Column(String)  # 直选推荐
 
     # verify attributes
-    v_kills = Column(String(50))
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
-    v_result_many = Column(String(50))
+    v_kills = Column(String)
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
+    v_result_many = Column(String)
 
     def get_verify(self):
         return [
@@ -309,24 +309,24 @@ class HuaWuQue(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save_location = Column(String(50))  # 定位胆码
-    position1 = Column(String(50))  # 百位
-    position2 = Column(String(50))  # 十位
-    position3 = Column(String(50))  # 个位
-    mix5 = Column(String(50))  # 5码复试
-    mix6 = Column(String(50))  # 6码复式
-    mix7 = Column(String(50))  # 7码复式
-    multi36 = Column(String(500))  # 组选推荐
+    save_location = Column(String)  # 定位胆码
+    position1 = Column(String)  # 百位
+    position2 = Column(String)  # 十位
+    position3 = Column(String)  # 个位
+    mix5 = Column(String)  # 5码复试
+    mix6 = Column(String)  # 6码复式
+    mix7 = Column(String)  # 7码复式
+    multi36 = Column(String)  # 组选推荐
 
     # verify attribute
-    v_save_location = Column(String(50))
-    v_position1 = Column(String(50))
-    v_position2 = Column(String(50))
-    v_position3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_multi36 = Column(String(50))
+    v_save_location = Column(String)
+    v_position1 = Column(String)
+    v_position2 = Column(String)
+    v_position3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_multi36 = Column(String)
 
     def get_verify(self):
         return [
@@ -347,32 +347,32 @@ class QingQiuJuShi(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    save3 = Column(String(50))  # 三胆
-    kill1 = Column(String(50))  # 杀一码
-    kill2 = Column(String(50))  # 杀二码
-    kill3 = Column(String(50))  # 杀三码
-    mix5 = Column(String(50))  # 五码
-    mix6 = Column(String(50))  # 六码
-    position_x = Column(String(50))  # 定位
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    multi6 = Column(String(500))  # 组选
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    save3 = Column(String)  # 三胆
+    kill1 = Column(String)  # 杀一码
+    kill2 = Column(String)  # 杀二码
+    kill3 = Column(String)  # 杀三码
+    mix5 = Column(String)  # 五码
+    mix6 = Column(String)  # 六码
+    position_x = Column(String)  # 定位
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    multi6 = Column(String)  # 组选
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_kill1 = Column(String(50))
-    v_kill2 = Column(String(50))
-    v_kill3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_position_x = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_kill1 = Column(String)
+    v_kill2 = Column(String)
+    v_kill3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_position_x = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -397,28 +397,28 @@ class ShiNaJiuWen(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save3 = Column(String(50))  # 胆码
-    mix4 = Column(String(50))  # 四码
-    mix5 = Column(String(50))  # 五码复式
-    mix6 = Column(String(50))  # 六码复式
-    mix7 = Column(String(50))  # 七码复式
-    position1 = Column(String(50))  # 百位定位推荐
-    position2 = Column(String(50))  # 十位定位推荐
-    position3 = Column(String(50))  # 个位定位推荐
-    result_many = Column(String(500))  # 直选精选
-    multi36 = Column(String(500))  # 组选大底
+    save3 = Column(String)  # 胆码
+    mix4 = Column(String)  # 四码
+    mix5 = Column(String)  # 五码复式
+    mix6 = Column(String)  # 六码复式
+    mix7 = Column(String)  # 七码复式
+    position1 = Column(String)  # 百位定位推荐
+    position2 = Column(String)  # 十位定位推荐
+    position3 = Column(String)  # 个位定位推荐
+    result_many = Column(String)  # 直选精选
+    multi36 = Column(String)  # 组选大底
 
     # verify attribute
-    v_save3 = Column(String(50))
-    v_mix4 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_position1 = Column(String(50))
-    v_position2 = Column(String(50))
-    v_position3 = Column(String(50))
-    v_result_many = Column(String(50))
-    v_multi36 = Column(String(50))
+    v_save3 = Column(String)
+    v_mix4 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_position1 = Column(String)
+    v_position2 = Column(String)
+    v_position3 = Column(String)
+    v_result_many = Column(String)
+    v_multi36 = Column(String)
 
     def get_verify(self):
         return [
@@ -441,26 +441,26 @@ class WanCaiLaoTou(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    save3 = Column(String(50))  # 三胆
-    mix5 = Column(String(50))  # 五码
-    mix6 = Column(String(50))  # 六码
-    mix7 = Column(String(50))  # 七码
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    multi6 = Column(String(500))  # 组六号码推荐
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    save3 = Column(String)  # 三胆
+    mix5 = Column(String)  # 五码
+    mix6 = Column(String)  # 六码
+    mix7 = Column(String)  # 七码
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    multi6 = Column(String)  # 组六号码推荐
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -482,28 +482,28 @@ class XiaoYanZi(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String(50))  # 独胆预测
-    save2 = Column(String(50))  # 双胆预测
-    save3 = Column(String(50))  # 三胆预测
-    mix5 = Column(String(50))  # 五码复式
-    mix6 = Column(String(50))  # 六码复式
-    mix7 = Column(String(50))  # 七码复式
-    he = Column(String(50))  # 推荐和值
-    span = Column(String(50))  # 推荐跨度
-    kills = Column(String(50))  # 排除号码
-    multi6 = Column(String(500))  # 组选号码
+    save1 = Column(String)  # 独胆预测
+    save2 = Column(String)  # 双胆预测
+    save3 = Column(String)  # 三胆预测
+    mix5 = Column(String)  # 五码复式
+    mix6 = Column(String)  # 六码复式
+    mix7 = Column(String)  # 七码复式
+    he = Column(String)  # 推荐和值
+    span = Column(String)  # 推荐跨度
+    kills = Column(String)  # 排除号码
+    multi6 = Column(String)  # 组选号码
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_kills = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_kills = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -526,32 +526,32 @@ class YueYeFeiLong(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    save3 = Column(String(50))  # 三胆
-    kill1 = Column(String(50))  # 杀一码
-    kill2 = Column(String(50))  # 杀二码
-    kill3 = Column(String(50))  # 杀三码
-    mix5 = Column(String(50))  # 五码
-    mix6 = Column(String(50))  # 六码
-    position_x = Column(String(50))  # 定位
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    multi6 = Column(String(500))  # 组选
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    save3 = Column(String)  # 三胆
+    kill1 = Column(String)  # 杀一码
+    kill2 = Column(String)  # 杀二码
+    kill3 = Column(String)  # 杀三码
+    mix5 = Column(String)  # 五码
+    mix6 = Column(String)  # 六码
+    position_x = Column(String)  # 定位
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    multi6 = Column(String)  # 组选
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_kill1 = Column(String(50))
-    v_kill2 = Column(String(50))
-    v_kill3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_position_x = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_kill1 = Column(String)
+    v_kill2 = Column(String)
+    v_kill3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_position_x = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -588,28 +588,28 @@ class ZiYunJian(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    position5_1 = Column(String(50))  # 555复式 百位
-    position5_2 = Column(String(50))  # 555复式 十位
-    position5_3 = Column(String(50))  # 555复式 个位
-    position3_1 = Column(String(50))  # 333复式 百位
-    position3_2 = Column(String(50))  # 333复式 十位
-    position3_3 = Column(String(50))  # 333复式 个位
-    save3 = Column(String(50))  # 三胆
-    mix4 = Column(String(50))  # 四码
-    mix5 = Column(String(50))  # 五码
-    multi36 = Column(String(500))  # 直,组推荐
+    position5_1 = Column(String)  # 555复式 百位
+    position5_2 = Column(String)  # 555复式 十位
+    position5_3 = Column(String)  # 555复式 个位
+    position3_1 = Column(String)  # 333复式 百位
+    position3_2 = Column(String)  # 333复式 十位
+    position3_3 = Column(String)  # 333复式 个位
+    save3 = Column(String)  # 三胆
+    mix4 = Column(String)  # 四码
+    mix5 = Column(String)  # 五码
+    multi36 = Column(String)  # 直,组推荐
 
     # verify attributes
-    v_position5_1 = Column(String(50))
-    v_position5_2 = Column(String(50))
-    v_position5_3 = Column(String(50))
-    v_position3_1 = Column(String(50))
-    v_position3_2 = Column(String(50))
-    v_position3_3 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_mix4 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_multi36 = Column(String(50))
+    v_position5_1 = Column(String)
+    v_position5_2 = Column(String)
+    v_position5_3 = Column(String)
+    v_position3_1 = Column(String)
+    v_position3_2 = Column(String)
+    v_position3_3 = Column(String)
+    v_save3 = Column(String)
+    v_mix4 = Column(String)
+    v_mix5 = Column(String)
+    v_multi36 = Column(String)
 
     def get_verify(self):
         return [
@@ -629,16 +629,16 @@ class ZiYunJian(ExpertSummary):
 class SportVerifyBase(Base):
     __abstract__ = True
 
-    inumabc = Column(String(50), primary_key=True)
+    inumabc = Column(String, primary_key=True)
     issue = Column(Integer)
     num = Column(Integer)
-    abc = Column(String(50))
-    result = Column(String(50))
+    abc = Column(String)
+    result = Column(String)
     score = Column(Float)
     num1 = Column(Integer)
     num2 = Column(Integer)
     num3 = Column(Integer)
-    verify = Column(String(50))
+    verify = Column(String)
 
     @classmethod
     def get_result_score_or_false(cls, issue_num_abc: str):
@@ -847,7 +847,7 @@ class SportNumber5(Base):
         session.merge(ins)
         session.commit()
         session.close()
-        print(f">>> merge kill in kills:{p_issue} - {p_numbers}")
+        print(f">>> P5 merge:{p_issue} - {p_numbers}")
 
     @classmethod
     def get_num1(cls, issue_number: int):
@@ -1082,18 +1082,18 @@ class SportFollowE(SportFollowX):
 class SportVerifyX(Base):
     __abstract__ = True
 
-    inumabc = Column(String(50), primary_key=True)
+    inumabc = Column(String, primary_key=True)
     issue = Column(Integer)
     num = Column(Integer)
-    abc = Column(String(50))
-    result = Column(String(50))
+    abc = Column(String)
+    result = Column(String)
     score = Column(Float)
     num1 = Column(Integer)
     num2 = Column(Integer)
     num3 = Column(Integer)
     num4 = Column(Integer)
     num5 = Column(Integer)
-    verify = Column(String(50))
+    verify = Column(String)
 
     @classmethod
     def get_result_score_or_false(cls, issue_num_abc: str):
@@ -1447,15 +1447,15 @@ class KillSport(Base):
     v_save
     """
     __tablename__ = 'p3_kill_sports'
-    issue_name = Column(String(50), primary_key=True)  # 期号_专家名
+    issue_name = Column(String, primary_key=True)  # 期号_专家名
 
     # attributes
-    issue = Column(String(50))  # 期号
-    name = Column(String(50))  # 专家名
-    save = Column(String(50))  # 组选
+    issue = Column(String)  # 期号
+    name = Column(String)  # 专家名
+    save = Column(String)  # 组选
 
     # verify attributes
-    v_save = Column(String(50))  # 组选成绩
+    v_save = Column(String)  # 组选成绩
 
     @classmethod
     def set_attributes_except_v(cls, issue_name, issue, name, save):
