@@ -1,6 +1,6 @@
 from sqlalchemy import Column, String, Integer, Float
 from sqlalchemy.ext.declarative import declarative_base
-from tools import get_engine, get_session
+from sqlalchemy_sqlite_session.tools import get_engine, get_session
 import json
 
 
@@ -16,6 +16,7 @@ def get_session_welfare():
     session = get_session()
     return session
 
+
 def get_engine_welfare():
     engine = get_engine()
     return engine
@@ -111,11 +112,11 @@ class WelfareNumber(Base):
     def add_number(cls, p_issue: str, p_numbers: list):
         """添加一条记录"""
         session = get_session_welfare()
-        ins = WelfareNumber([p_issue] + p_numbers)
+        ins = cls([p_issue] + p_numbers)
         session.merge(ins)
         session.commit()
         session.close()
-        print(f">>> merge kill in kills:{p_issue} - {p_numbers}")
+        print(f">>> 3D merge:{p_issue} - {p_numbers}")
 
 
 class ExpertSummary(Base):
@@ -201,32 +202,32 @@ class BaXianGuoHai(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    kill1 = Column(String(50))  # 本期杀码
-    save1 = Column(String(50))  # 毒胆参考
-    save2 = Column(String(50))  # 双胆预测
-    save3 = Column(String(50))  # 胆码推荐
-    mix4 = Column(String(50))  # 精选四码
-    mix5 = Column(String(50))  # 主打五码
-    mix6 = Column(String(50))  # 缩水六码
-    mix7 = Column(String(50))  # 盈利七码
-    he = Column(String(50))  # 重点和值
-    span = Column(String(50))  # 跨度参考
-    multi6 = Column(String(500))  # 精选单注
-    multi3 = Column(String(500))  # 防组选三
+    kill1 = Column(String)  # 本期杀码
+    save1 = Column(String)  # 毒胆参考
+    save2 = Column(String)  # 双胆预测
+    save3 = Column(String)  # 胆码推荐
+    mix4 = Column(String)  # 精选四码
+    mix5 = Column(String)  # 主打五码
+    mix6 = Column(String)  # 缩水六码
+    mix7 = Column(String)  # 盈利七码
+    he = Column(String)  # 重点和值
+    span = Column(String)  # 跨度参考
+    multi6 = Column(String)  # 精选单注
+    multi3 = Column(String)  # 防组选三
 
     # verify attributes
-    v_kill1 = Column(String(50))
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_mix4 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
-    v_multi3 = Column(String(50))
+    v_kill1 = Column(String)
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_mix4 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
+    v_multi3 = Column(String)
 
     def get_verify(self):
         return [
@@ -251,26 +252,26 @@ class DaLaoRen(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save3 = Column(String(50))  # 胆码
-    save1 = Column(String(50))  # 金胆
-    mix6 = Column(String(50))  # 复式组选
-    kill1 = Column(String(50))  # 杀码
-    shape = Column(String(50))  # 重点
-    d2_combine = Column(String(50))  # 二码组合
-    kill_d2_combine = Column(String(50))  # 杀二码组合
-    multi6 = Column(String(500))  # 组选大底
-    multi12 = Column(String(500))  # 精选12注
+    save3 = Column(String)  # 胆码
+    save1 = Column(String)  # 金胆
+    mix6 = Column(String)  # 复式组选
+    kill1 = Column(String)  # 杀码
+    shape = Column(String)  # 重点
+    d2_combine = Column(String)  # 二码组合
+    kill_d2_combine = Column(String)  # 杀二码组合
+    multi6 = Column(String)  # 组选大底
+    multi12 = Column(String)  # 精选12注
 
     # verify attributes
-    v_save3 = Column(String(50))  # 胆码
-    v_save1 = Column(String(50))  # 金胆
-    v_mix6 = Column(String(50))  # 复式组选
-    v_kill1 = Column(String(50))  # 杀码
-    v_shape = Column(String(50))  # 重点
-    v_d2_combine = Column(String(50))  # 二码组合
-    v_kill_d2_combine = Column(String(50))  # 杀二码组合
-    v_multi6 = Column(String(50))  # 组选大底
-    v_multi12 = Column(String(50))  # 精选12注
+    v_save3 = Column(String)  # 胆码
+    v_save1 = Column(String)  # 金胆
+    v_mix6 = Column(String)  # 复式组选
+    v_kill1 = Column(String)  # 杀码
+    v_shape = Column(String)  # 重点
+    v_d2_combine = Column(String)  # 二码组合
+    v_kill_d2_combine = Column(String)  # 杀二码组合
+    v_multi6 = Column(String)  # 组选大底
+    v_multi12 = Column(String)  # 精选12注
 
     def get_verify(self):
         return [
@@ -292,32 +293,32 @@ class QingQiuJuShi(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    save3 = Column(String(50))  # 三胆
-    kill1 = Column(String(50))  # 杀一码
-    kill2 = Column(String(50))  # 杀二码
-    kill3 = Column(String(50))  # 杀三码
-    mix5 = Column(String(50))  # 五码
-    mix6 = Column(String(50))  # 六码
-    position_x = Column(String(50))  # 定位
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    multi6 = Column(String(500))  # 组选
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    save3 = Column(String)  # 三胆
+    kill1 = Column(String)  # 杀一码
+    kill2 = Column(String)  # 杀二码
+    kill3 = Column(String)  # 杀三码
+    mix5 = Column(String)  # 五码
+    mix6 = Column(String)  # 六码
+    position_x = Column(String)  # 定位
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    multi6 = Column(String)  # 组选
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_kill1 = Column(String(50))
-    v_kill2 = Column(String(50))
-    v_kill3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_position_x = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_kill1 = Column(String)
+    v_kill2 = Column(String)
+    v_kill3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_position_x = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -342,28 +343,28 @@ class ShiNaJiuWen(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save3 = Column(String(50))  # 胆码
-    mix4 = Column(String(50))  # 四码
-    mix5 = Column(String(50))  # 五码复式
-    mix6 = Column(String(50))  # 六码复式
-    mix7 = Column(String(50))  # 七码复式
-    position1 = Column(String(50))  # 百位定位推荐
-    position2 = Column(String(50))  # 十位定位推荐
-    position3 = Column(String(50))  # 个位定位推荐
-    result_many = Column(String(500))  # 直选精选
-    multi36 = Column(String(500))  # 组选大底
+    save3 = Column(String)  # 胆码
+    mix4 = Column(String)  # 四码
+    mix5 = Column(String)  # 五码复式
+    mix6 = Column(String)  # 六码复式
+    mix7 = Column(String)  # 七码复式
+    position1 = Column(String)  # 百位定位推荐
+    position2 = Column(String)  # 十位定位推荐
+    position3 = Column(String)  # 个位定位推荐
+    result_many = Column(String)  # 直选精选
+    multi36 = Column(String)  # 组选大底
 
     # verify attribute
-    v_save3 = Column(String(50))
-    v_mix4 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_mix7 = Column(String(50))
-    v_position1 = Column(String(50))
-    v_position2 = Column(String(50))
-    v_position3 = Column(String(50))
-    v_result_many = Column(String(50))
-    v_multi36 = Column(String(50))
+    v_save3 = Column(String)
+    v_mix4 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_mix7 = Column(String)
+    v_position1 = Column(String)
+    v_position2 = Column(String)
+    v_position3 = Column(String)
+    v_result_many = Column(String)
+    v_multi36 = Column(String)
 
     def get_verify(self):
         return [
@@ -386,28 +387,28 @@ class WanCaiLaoTou(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    kills = Column(String(50))  # 杀码
-    position_star = Column(String(50))  # 包星
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    mix5 = Column(String(50))  # 5码复式
-    mix6 = Column(String(50))  # 6码复式
-    he = Column(String(50))  # 和值范围
-    span = Column(String(50))  # 跨度范围
-    multi6 = Column(String(500))  # 组选
-    result_many = Column(String(500))  # 单选
+    kills = Column(String)  # 杀码
+    position_star = Column(String)  # 包星
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    mix5 = Column(String)  # 5码复式
+    mix6 = Column(String)  # 6码复式
+    he = Column(String)  # 和值范围
+    span = Column(String)  # 跨度范围
+    multi6 = Column(String)  # 组选
+    result_many = Column(String)  # 单选
 
     # verify attributes
-    v_kills = Column(String(50))
-    v_position_star = Column(String(50))
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
-    v_result_many = Column(String(50))
+    v_kills = Column(String)
+    v_position_star = Column(String)
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
+    v_result_many = Column(String)
 
     def get_verify(self):
         return [
@@ -429,32 +430,32 @@ class XiaoWei(ExpertSummary):
     _name_ = '小微'
     issue = Column(Integer, primary_key=True)
     # attributes
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    save3 = Column(String(50))  # 三胆
-    kill1 = Column(String(50))  # 杀一码
-    kill2 = Column(String(50))  # 杀二码
-    kill3 = Column(String(50))  # 杀三码
-    mix5 = Column(String(50))  # 五码
-    mix6 = Column(String(50))  # 六码
-    position_x = Column(String(50))  # 定位
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    multi6 = Column(String(500))  # 组选
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    save3 = Column(String)  # 三胆
+    kill1 = Column(String)  # 杀一码
+    kill2 = Column(String)  # 杀二码
+    kill3 = Column(String)  # 杀三码
+    mix5 = Column(String)  # 五码
+    mix6 = Column(String)  # 六码
+    position_x = Column(String)  # 定位
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    multi6 = Column(String)  # 组选
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_kill1 = Column(String(50))
-    v_kill2 = Column(String(50))
-    v_kill3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_position_x = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_kill1 = Column(String)
+    v_kill2 = Column(String)
+    v_kill3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_position_x = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -479,32 +480,32 @@ class YueYeFeiLong(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    save3 = Column(String(50))  # 三胆
-    kill1 = Column(String(50))  # 杀一码
-    kill2 = Column(String(50))  # 杀二码
-    kill3 = Column(String(50))  # 杀三码
-    mix5 = Column(String(50))  # 五码
-    mix6 = Column(String(50))  # 六码
-    position_x = Column(String(50))  # 定位
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    multi6 = Column(String(500))  # 组选
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    save3 = Column(String)  # 三胆
+    kill1 = Column(String)  # 杀一码
+    kill2 = Column(String)  # 杀二码
+    kill3 = Column(String)  # 杀三码
+    mix5 = Column(String)  # 五码
+    mix6 = Column(String)  # 六码
+    position_x = Column(String)  # 定位
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    multi6 = Column(String)  # 组选
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_kill1 = Column(String(50))
-    v_kill2 = Column(String(50))
-    v_kill3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_position_x = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_kill1 = Column(String)
+    v_kill2 = Column(String)
+    v_kill3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_position_x = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -528,32 +529,32 @@ class ZhouXingXing(ExpertSummary):
     _name_ = '周星星'
     issue = Column(Integer, primary_key=True)
     # attributes
-    save1 = Column(String(50))  # 独胆
-    save2 = Column(String(50))  # 双胆
-    save3 = Column(String(50))  # 三胆
-    kill1 = Column(String(50))  # 杀一码
-    kill2 = Column(String(50))  # 杀二码
-    kill3 = Column(String(50))  # 杀三码
-    mix5 = Column(String(50))  # 五码
-    mix6 = Column(String(50))  # 六码
-    position_x = Column(String(50))  # 定位
-    he = Column(String(50))  # 和值
-    span = Column(String(50))  # 跨度
-    multi6 = Column(String(500))  # 组选
+    save1 = Column(String)  # 独胆
+    save2 = Column(String)  # 双胆
+    save3 = Column(String)  # 三胆
+    kill1 = Column(String)  # 杀一码
+    kill2 = Column(String)  # 杀二码
+    kill3 = Column(String)  # 杀三码
+    mix5 = Column(String)  # 五码
+    mix6 = Column(String)  # 六码
+    position_x = Column(String)  # 定位
+    he = Column(String)  # 和值
+    span = Column(String)  # 跨度
+    multi6 = Column(String)  # 组选
 
     # verify attributes
-    v_save1 = Column(String(50))
-    v_save2 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_kill1 = Column(String(50))
-    v_kill2 = Column(String(50))
-    v_kill3 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_mix6 = Column(String(50))
-    v_position_x = Column(String(50))
-    v_he = Column(String(50))
-    v_span = Column(String(50))
-    v_multi6 = Column(String(50))
+    v_save1 = Column(String)
+    v_save2 = Column(String)
+    v_save3 = Column(String)
+    v_kill1 = Column(String)
+    v_kill2 = Column(String)
+    v_kill3 = Column(String)
+    v_mix5 = Column(String)
+    v_mix6 = Column(String)
+    v_position_x = Column(String)
+    v_he = Column(String)
+    v_span = Column(String)
+    v_multi6 = Column(String)
 
     def get_verify(self):
         return [
@@ -590,28 +591,28 @@ class ZiYunJian(ExpertSummary):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    position5_1 = Column(String(50))  # 555复式 百位
-    position5_2 = Column(String(50))  # 555复式 十位
-    position5_3 = Column(String(50))  # 555复式 个位
-    position3_1 = Column(String(50))  # 333复式 百位
-    position3_2 = Column(String(50))  # 333复式 十位
-    position3_3 = Column(String(50))  # 333复式 个位
-    save3 = Column(String(50))  # 三胆
-    mix4 = Column(String(50))  # 四码
-    mix5 = Column(String(50))  # 五码
-    multi36 = Column(String(500))  # 直,组推荐
+    position5_1 = Column(String)  # 555复式 百位
+    position5_2 = Column(String)  # 555复式 十位
+    position5_3 = Column(String)  # 555复式 个位
+    position3_1 = Column(String)  # 333复式 百位
+    position3_2 = Column(String)  # 333复式 十位
+    position3_3 = Column(String)  # 333复式 个位
+    save3 = Column(String)  # 三胆
+    mix4 = Column(String)  # 四码
+    mix5 = Column(String)  # 五码
+    multi36 = Column(String)  # 直,组推荐
 
     # verify attributes
-    v_position5_1 = Column(String(50))
-    v_position5_2 = Column(String(50))
-    v_position5_3 = Column(String(50))
-    v_position3_1 = Column(String(50))
-    v_position3_2 = Column(String(50))
-    v_position3_3 = Column(String(50))
-    v_save3 = Column(String(50))
-    v_mix4 = Column(String(50))
-    v_mix5 = Column(String(50))
-    v_multi36 = Column(String(50))
+    v_position5_1 = Column(String)
+    v_position5_2 = Column(String)
+    v_position5_3 = Column(String)
+    v_position3_1 = Column(String)
+    v_position3_2 = Column(String)
+    v_position3_3 = Column(String)
+    v_save3 = Column(String)
+    v_mix4 = Column(String)
+    v_mix5 = Column(String)
+    v_multi36 = Column(String)
 
     def get_verify(self):
         return [
@@ -637,12 +638,12 @@ class Pullze(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    mix7 = Column(String(50))  # 七码 \d{7}
-    group3 = Column(String(50))  # 三组 (\d{3})(\d{3})(\d{3})
+    mix7 = Column(String)  # 七码 \d{7}
+    group3 = Column(String)  # 三组 (\d{3})(\d{3})(\d{3})
 
     # verify attributes
-    v_mix7 = Column(String(50))
-    v_group3 = Column(String(50))
+    v_mix7 = Column(String)
+    v_group3 = Column(String)
 
     @classmethod
     def get_mix7_by_issue(cls, issue_target) -> list:
@@ -774,15 +775,15 @@ class WelfareExpertFSS(Base):
     v_save
     """
     __tablename__ = 'sd_fss_experts'
-    issue_name = Column(String(50), primary_key=True)  # 期号_专家名
+    issue_name = Column(String, primary_key=True)  # 期号_专家名
 
     # attributes
-    issue = Column(String(50))  # 期号
-    name = Column(String(50))  # 专家名
-    save = Column(String(50))  # 组选
+    issue = Column(String)  # 期号
+    name = Column(String)  # 专家名
+    save = Column(String)  # 组选
 
     # verify attributes
-    v_save = Column(String(50))  # 组选成绩
+    v_save = Column(String)  # 组选成绩
 
     @classmethod
     def set_attributes_except_v(cls, issue_name: str, issue: str, name: str, save: str):
@@ -847,15 +848,15 @@ class WelfareExpertOTT(Base):
     v_save
     """
     __tablename__ = 'sd_ott_experts'
-    issue_name = Column(String(50), primary_key=True)  # 期号_专家名
+    issue_name = Column(String, primary_key=True)  # 期号_专家名
 
     # attributes
-    issue = Column(String(50))  # 期号
-    name = Column(String(50))  # 专家名
-    save = Column(String(50))  # 组选
+    issue = Column(String)  # 期号
+    name = Column(String)  # 专家名
+    save = Column(String)  # 组选
 
     # verify attributes
-    v_save = Column(String(50))  # 组选成绩
+    v_save = Column(String)  # 组选成绩
 
     @classmethod
     def set_attributes_except_v(cls, issue_name: str, issue: str, name: str, save: str):
@@ -914,16 +915,16 @@ class WelfareExpertOTT(Base):
 class WelfareVerifyBase(Base):
     __abstract__ = True
 
-    inumabc = Column(String(50), primary_key=True)
+    inumabc = Column(String, primary_key=True)
     issue = Column(Integer)
     num = Column(Integer)
-    abc = Column(String(50))
-    result = Column(String(50))
+    abc = Column(String)
+    result = Column(String)
     score = Column(Float)
     num1 = Column(Integer)
     num2 = Column(Integer)
     num3 = Column(Integer)
-    verify = Column(String(50))
+    verify = Column(String)
 
     @classmethod
     def get_result_score_or_false(cls, issue_num_abc: str):
@@ -1078,16 +1079,16 @@ class WelfareVerifyN(WelfareVerifyBase):
 class WelfareVerifyAbstract(Base):
     __abstract__ = True
 
-    inumabc = Column(String(50), primary_key=True)
+    inumabc = Column(String, primary_key=True)
     issue = Column(Integer)
     num = Column(Integer)
-    abc = Column(String(50))
-    result = Column(String(50))
+    abc = Column(String)
+    result = Column(String)
     score = Column(Float)
     num1 = Column(Integer)
     num2 = Column(Integer)
     num3 = Column(Integer)
-    verify = Column(String(50))
+    verify = Column(String)
 
     @classmethod
     def get_result_score_or_false(cls, issue_num_abc: str):
@@ -1558,17 +1559,109 @@ class WelfareFollowN(Base):
 class History(Base):
     __tablename__ = 'historys'
 
-    issue_item = Column(String(255), primary_key=True)
+    issue_item = Column(String, primary_key=True)
     issue = Column(Integer)
-    item = Column(String(255))
+    item = Column(String)
     score = Column(Float)
-    length_xy = Column(String(255))
-    length_pr = Column(String(255))
+    length_xy = Column(String)
+    length_pr = Column(String)
 
     def __str__(self) -> str:
         return f'{self.issue_item}, {self.score}'
-        
-   
+
+
+class KillWelfare(Base):
+    """
+    issue
+    name
+    issue_name
+    save
+    v_save
+    """
+    __tablename__ = 'sd_kill_welfares'
+    issue_name = Column(String, primary_key=True)  # 期号_专家名
+
+    # attributes
+    issue = Column(String)  # 期号
+    name = Column(String)  # 专家名
+    save = Column(String)  # 组选
+
+    # verify attributes
+    v_save = Column(String)  # 组选成绩
+
+    @classmethod
+    def set_attributes_except_v(cls, issue_name, issue, name, save):
+        """更新数据库内容: 除了验证项目
+
+        Args:
+            issue_name(str): issue + _ + name
+            issue(str): 期号
+            name(str): name
+            save(str): save
+            path(str): 数据库保存目录
+        Returns: None
+        """
+        # create instance
+        session = cls.get_session()
+        ins = cls()
+        ins.issue_name = issue_name
+        ins.issue = issue
+        ins.name = name
+        ins.save = save
+        print(f">>> 合并数据成功, 期号_专家名: {issue_name}, save: {save}")
+        session.merge(ins)
+        session.commit()
+        session.close()
+
+    @classmethod
+    def set_attribute(cls, issue_name, attribute_name, data, path):
+        """更新数据库的某项
+
+        Args:
+            issue_name(str): issue + _ + name, 定位数据表的某条数据
+            attribute_name(str): 数据表的列
+            data(str): 保存的数据
+            path(str): 数据库保存目录
+        Returns: None
+        """
+        # 获取表的字段名称集合
+        # total_names = [str(x) for x in cls.metadata.tables[cls.__tablename__].columns]
+        # attributes = [x.replace(f'{cls.__tablename__}.', '') for x in total_names]
+        session = cls.get_session()
+        ins = cls()
+        ins.issue_name = issue_name
+        # 选择属性
+        if attribute_name == 'issue_name':
+            pass
+        elif attribute_name == 'issue':
+            ins.issue = data
+        elif attribute_name == 'name':
+            ins.name = data
+        elif attribute_name == 'save':
+            ins.save = data
+        elif attribute_name == 'v_save':
+            ins.v_save = data
+        else:
+            raise Exception(f">>> 数据表《{cls._name_}》属性名称错误!!!")
+        print(f">>> 合并数据成功: {issue_name}, {attribute_name}: {data}")
+        session.merge(ins)
+        session.commit()
+        session.close()
+
+    @classmethod
+    def get_verify(cls):
+        return cls.v_save
+
+    @staticmethod
+    def get_engine():
+        db_engine = get_engine_welfare()
+        return db_engine
+
+    @staticmethod
+    def get_session():
+        session = get_session_welfare()
+        return session
+
 
 if __name__ == "__main__":
     # WelfareVerify.add_score('20212882945', 2021288, 2, '945', 'y', 0.49)
